
/**
	Set contents of the tag with given id.
*/
function setInnerHTML(id, html)
{
	var tag = document.getElementById(id);
	if (!tag) alert('No tag with id='+id);
	tag.innerHTML = html;
}

/**
	Execute the given method when the TAB key is pressed. A short
	delay is added so the method doesn't interfer with normal event
	handling.
	
	@param event The event object with information about what happened
	@param method The method to execute when TAB is pressed
*/
function doOnTab(event, method)
{
	if (event.keyCode == 9) 
	{
		setTimeout(method, 200);
	}
	return true;
}

/**
	Execute the given method when the TAB or ENTER key is pressed. 
	A short delay is added so the method doesn't interfer with normal 
	event handling.
	
 	@param event The event object with information about what happened
	@param method The method to execute when TAB is pressed
 */
function doOnTabOrEnter(event, method)
{
	if (event.keyCode == 9 || event.keyCode == 13) 
	{
		setTimeout(method, 200);
	}
	return true;
}

/**
	Switch focus to the given input field if the ENTER key is pressed.
	If no form name is given, the input field must be on the same form
	as the field that receives the event.
	
 	@param event The event object with information about what happened
 	@param inputFieldName The name of the input field which should get focus next
*/
function focusOnEnter(event, inputFieldName, formName)
{
	if (event.keyCode == 13) 
	{
		var frm;
		if (formName)
		{
			frm = document.forms[formName];
		}
		else
		{
			var currentField = event.target || event.srcElement;
			if (currentField) frm = currentField.form;
		}
		if (frm)
		{
			var nextField = frm[inputFieldName];
			if (nextField) nextField.focus();
		}
	}
	return true;
}

/**
	Set status for an input field.
	@param prefix The prefix to use for finding <div> and other tags
	@param message The message (may be empty)
	@param clazz The message clazz (valid, invalid, warning) or empty
*/
function setInputStatus(prefix, message, clazz)
{
	var tag = document.getElementById(prefix + '.status');
	tag.className = 'status ' + clazz;
	
	setInnerHTML(prefix + '.message', message);
	if (message)
	{
		Main.showInline(prefix + '.message');
	}
	else
	{
		Main.hide(prefix + '.message');
	}
}

/**
	Display a fatal error message and disable all form controls and
	hide all buttons except the 'gorestart' button. A <div> tag with
	the id=errorMessage is assumed.
	
	@param message The error message to display
*/
function setFatalError(message)
{
	setInnerHTML('errorMessage', message);
	Main.show('errorMessage');
	var buttons = Main.getElementsByTagAndClassName('div', 'buttonclass');
	for (var i = 0; i < buttons.length; i++)
	{
		if (buttons[i].id) buttons[i].style.display = 'none';
	}
	Main.show('gorestart');
	for (var fi = 0; fi < document.forms.length; fi++)
	{
		var frm = document.forms[fi];
		for (var ei = 0; ei < frm.elements.length; ei++)
		{
			frm.elements[ei].disabled = true;	
		}
	}
}

/**
	Cancel the current registration and re-start the wizard from the beginning.
	@param force If set, the wizard is re-started without confirmation
*/
function goRestart(force)
{
	if (!force && !confirm('Cancel this registration?')) return;
	location.href = location.href;
}
